@@ -5,7 +5,6 @@ use warnings;
 
 use Cwd;
 use English qw(-no_match_vars);
-use Sys::Hostname;
 use UNIVERSAL::require;
 use File::Glob;
 
@@ -19,9 +18,10 @@ use FusionInventory::Agent::Target::Local;
 use FusionInventory::Agent::Target::Server;
 use FusionInventory::Agent::Target::Stdout;
 use FusionInventory::Agent::Tools;
+use FusionInventory::Agent::Tools::Hostname;
 use FusionInventory::Agent::XML::Query::Prolog;
 
-our $VERSION = '2.1.9902';
+our $VERSION = '2.1.9904';
 our $VERSION_STRING = 
     "FusionInventory unified agent for UNIX, Linux and MacOSX ($VERSION)";
 our $AGENT_STRING =
@@ -34,6 +34,7 @@ sub new {
         status  => 'unknown',
         confdir => $params{confdir},
         datadir => $params{datadir},
+        libdir  => $params{libdir},
         vardir  => $params{vardir},
     };
     bless $self, $class;
@@ -64,6 +65,7 @@ sub init {
     $logger->debug("Configuration directory: $self->{confdir}");
     $logger->debug("Data directory: $self->{datadir}");
     $logger->debug("Storage directory: $self->{vardir}");
+    $logger->debug("Lib directory: $self->{libdir}");
 
     $self->{storage} = FusionInventory::Agent::Storage->new(
         logger    => $logger,
@@ -177,10 +179,10 @@ sub init {
     }
 
     # compute list of allowed tasks
-    my %available = $self->getAvailableTasks();
-    my %disabled  = map { lc($_) => 1 } @{$config->{'no-task'}};
-    my @allowed   = grep { !$disabled{lc($_)} } keys %available;
-    $self->{tasks} = \@allowed;
+    my %available = $self->getAvailableTasks(disabledTasks => $config->{'no-task'});
+    my @tasks = keys %available;
+
+    $self->{tasks} = \@tasks;
 
     $logger->debug("FusionInventory Agent initialised");
 }
@@ -314,48 +316,43 @@ sub getStatus {
 }
 
 sub getAvailableTasks {
-    my ($self) = @_;
+    my ($self, %params) = @_;
 
     my $logger = $self->{logger};
     my %tasks;
+    my %disabled  = map { lc($_) => 1 } @{$params{disabledTasks}};
 
-    # tasks may be dispatched in every directory referenced in @INC
-    foreach my $directory (@INC) {
-        # look for a suitable subdirectory
-        my $subdirectory = "FusionInventory/Agent/Task";
-        next unless -d "$directory/$subdirectory";
+    # tasks may be located only in agent libdir
+    my $directory = $self->{libdir};
+    $directory =~ s,\\,/,g;
+    my $subdirectory = "FusionInventory/Agent/Task";
+    # look for all perl modules here
+    foreach my $file (File::Glob::glob("$directory/$subdirectory/*.pm")) {
+        next unless $file =~ m{($subdirectory/(\S+)\.pm)$};
+        my $module = file2module($1);
+        my $name = file2module($2);
 
-        # look for all perl modules here
-        foreach my $file (File::Glob::glob("$directory/$subdirectory/*.pm")) {
-            next unless $file =~ m{($subdirectory/(\S+)\.pm)$};
-            my $module = file2module($1);
-            my $name = file2module($2);
-            # check module
-            # todo: use a child process when running as a server to save memory
-            if (!$module->require()) {
-                $logger->debug2("module $module does not compile: $@") if $logger;
-                next;
-            }
-            if (!$module->isa('FusionInventory::Agent::Task')) {
-                $logger->debug2("module $module is not a task") if $logger;
-                next;
-            }
+        next if $disabled{lc($name)};
 
-            next unless $module->require();
-            next unless $module->isa('FusionInventory::Agent::Task');
-
-            # only the first seen will be loaded
-            next if defined $tasks{$module};
-            
-            # retrieve version
-            my $version;
-            {
-                no strict 'refs';  ## no critic
-                $version = ${$module . '::VERSION'};
-            }
-
-            $tasks{$name} = $version;
+        # check module
+        # todo: use a child process when running as a server to save memory
+        if (!$module->require()) {
+            $logger->debug2("module $module does not compile") if $logger;
+            next;
         }
+        if (!$module->isa('FusionInventory::Agent::Task')) {
+            $logger->debug2("module $module is not a task") if $logger;
+            next;
+        }
+
+        # retrieve version
+        my $version;
+        {
+            no strict 'refs';  ## no critic
+            $version = ${$module . '::VERSION'};
+        }
+
+        $tasks{$name} = $version;
     }
 
     return %tasks;
@@ -375,31 +372,6 @@ sub _isAlreadyRunning {
     return Proc::PID::File->running();
 }
 
-sub _getHostname {
-
-    # use hostname directly under Unix
-    return hostname() if $OSNAME ne 'MSWin32';
-
-    # otherwise, use Win32 API
-    Encode->require();
-    Encode->import();
-    Win32::API->require();
-
-    my $getComputerName = Win32::API->new(
-        "kernel32", "GetComputerNameExW", ["I", "P", "P"], "N"
-    );
-    my $lpBuffer = "\x00" x 1024;
-    my $N = 1024; #pack ("c4", 160,0,0,0);
-
-    $getComputerName->Call(3, $lpBuffer, $N);
-
-    # GetComputerNameExW returns the string in UTF16, we have to change
-    # it to UTF8
-    return encode(
-        "UTF-8", substr(decode("UCS-2le", $lpBuffer), 0, ord $N)
-    );
-}
-
 sub _loadState {
     my ($self) = @_;
 
@@ -429,7 +401,7 @@ sub _computeToken {
 
 # compute an unique agent identifier, based on host name and current time
 sub _computeDeviceId {
-    my $hostname = _getHostname();
+    my $hostname = FusionInventory::Agent::Tools::Hostname::getHostname();
 
     my ($year, $month , $day, $hour, $min, $sec) =
         (localtime (time))[5, 4, 3, 2, 1, 0];
@@ -476,6 +448,10 @@ the options to use.
 
 =back
 
+=head2 init()
+
+Initialize the agent.
+
 =head2 run()
 
 Run the agent.
