@@ -22,23 +22,23 @@ sub new {
         if $params{ca_cert_dir} && ! -d $params{ca_cert_dir};
 
     my $self = {
-        logger         => $params{logger} ||
+        logger       => $params{logger} ||
                           FusionInventory::Agent::Logger->new(),
-        user           => $params{user},
-        password       => $params{password},
-        timeout        => $params{timeout} || 180,
-        ssl_set        => 0,
-        no_ssl_check   => $params{no_ssl_check},
-        ca_cert_dir    => $params{ca_cert_dir},
-        ca_cert_file   => $params{ca_cert_file}
+        user         => $params{user},
+        password     => $params{password},
+        timeout      => $params{timeout} || 180,
+        ssl_set      => 0,
+        no_ssl_check => $params{no_ssl_check},
+        ca_cert_dir  => $params{ca_cert_dir},
+        ca_cert_file => $params{ca_cert_file}
     };
     bless $self, $class;
 
     # create user agent
     $self->{ua} = LWP::UserAgent->new(
-            parse_head => 0, # No need to parse HTML
-            keep_alive => 1,
-            requests_redirectable => ['POST', 'GET', 'HEAD']
+        parse_head => 0, # No need to parse HTML
+        keep_alive => 1,
+        requests_redirectable => ['POST', 'GET', 'HEAD']
     );
 
     if ($params{proxy}) {
@@ -129,18 +129,19 @@ sub _setSSLOptions {
 
     # SSL handling
     if ($self->{'no_ssl_check'}) {
-        if ($LWP::VERSION >= 6) {
-            # LWP6 default behavior is to check the SSL hostname
-            $self->{ua}->ssl_opts(verify_hostname => 0);
-        }
+# IO::Socket::SSL default behavior is to check the SSL hostname
+# We run it in a eval to avoid break if the ssl_opts doesn't work on some
+# old LWP
+       eval { $self->{ua}->ssl_opts(verify_hostname => 0); }
     } else {
         # only IO::Socket::SSL can perform full server certificate validation,
         # Net::SSL is only able to check certification authority, and not
         # certificate hostname
         IO::Socket::SSL->require();
         die
-            "failed to load IO::Socket::SSL" .
-            ", unable to perform SSL certificate validation"
+            "failed to load IO::Socket::SSL, "                 .
+            "unable to perform SSL certificate validation.\n"  .
+            "You can use 'no-ssl-check' option to disable it."
             if $EVAL_ERROR;
 
         if ($LWP::VERSION >= 6) {
@@ -149,6 +150,13 @@ sub _setSSLOptions {
             $self->{ua}->ssl_opts(SSL_ca_path => $self->{'ca_cert_dir'})
                 if $self->{'ca_cert_dir'};
         } else {
+            # SSL_verifycn_scheme and SSL_verifycn_name are required
+            die 
+                "IO::Socket::SSL $IO::Socket::SSL::VERSION is too old, "     .
+                "version 1.14 is required for SSL certificate validation.\n" .
+                " You can use 'no-ssl-check' option to disable SSL it."
+                if $IO::Socket::SSL::VERSION < 1.14;
+
             # use a custom HTTPS handler to workaround default LWP5 behaviour
             FusionInventory::Agent::HTTP::Protocol::https->use(
                 ca_cert_file => $self->{'ca_cert_file'},
@@ -156,7 +164,8 @@ sub _setSSLOptions {
             );
             die 
                 "failed to load FusionInventory::Agent::HTTP::Protocol::https" .
-                ", unable to perform SSL certificate validation"
+                ", unable to perform SSL certificate validation.\n"            .
+                "You can use 'no-ssl-check' option to disable it."
                 if $EVAL_ERROR;
 
             LWP::Protocol::implementor(
