@@ -37,11 +37,11 @@ sub _getPackagesListFromPkgInfo {
 
     my @packages;
     while (my $line = <$handle>) {
-        next unless $line =~ /^(\S+)-(\d+\S*)\s+(.*)/;
+        next unless $line =~ /^(\S+) - (\S+) \s+ (.*)/x;
         push @packages, {
-            NAME    => $1,
-            VERSION => $2,
-            DESCRIPTION => $3
+            NAME     => $1,
+            VERSION  => $2,
+            COMMENTS => $3
         };
     }
 
