@@ -22,24 +22,19 @@ sub doInventory {
 
     # get the list of network interfaces
     my $routes = getRoutingTable(command => 'netstat -nr', logger => $logger);
-    my @interfaces = _getInterfaces(logger => $logger, routes => $routes);
+    my @interfaces = _getInterfaces(logger => $logger);
 
     foreach my $interface (@interfaces) {
+        $interface->{IPGATEWAY} = $params{routes}->{$interface->{IPSUBNET}}
+            if $interface->{IPSUBNET};
+
         $inventory->addEntry(
             section => 'NETWORKS',
             entry   => $interface
         );
     }
 
-    # set global parameters
-    my @ip_addresses =
-        grep { ! /^127/ }
-        grep { $_ }
-        map { $_->{IPADDRESS} }
-        @interfaces;
-
     $inventory->setHardware({
-        IPADDR         => join('/', @ip_addresses),
         DEFAULTGATEWAY => $routes->{'0.0.0.0'}
     });
 }
@@ -79,19 +74,6 @@ sub _getInterfaces {
 
         $interface->{IPDHCP} = getIpDhcp($logger, $interface->{DESCRIPTION});
         $interface->{SLAVES} = _getSlaves($interface->{DESCRIPTION});
-
-        if ($interface->{IPSUBNET}) {
-            $interface->{IPGATEWAY} = $routes->{$interface->{IPSUBNET}};
-
-            # replace '0.0.0.0' (ie 'default gateway') by the
-            # default gateway IP adress if it exists
-            if ($interface->{IPGATEWAY} and
-                $interface->{IPGATEWAY} eq '0.0.0.0' and 
-                $routes->{'0.0.0.0'}
-            ) {
-                $interface->{IPGATEWAY} = $routes->{'0.0.0.0'}
-            }
-        }
     }
 
     return @interfaces;
@@ -159,9 +141,9 @@ sub _getUevent {
     return unless $handle;
 
     my ($driver, $pcislot);
-    while (<$handle>) {
-        $driver = $1 if /^DRIVER=(\S+)/;
-        $pcislot = $1 if /^PCI_SLOT_NAME=(\S+)/;
+    while (my $line = <$handle>) {
+        $driver = $1 if $line =~ /^DRIVER=(\S+)/;
+        $pcislot = $1 if $line =~ /^PCI_SLOT_NAME=(\S+)/;
     }
     close $handle;
 
