@@ -82,6 +82,10 @@ sub doInventory {
 
     }
 
+    foreach (keys %$bios) {
+        $bios->{$_} =~ s/\s+$// if $bios->{$_};
+    }
+
     $inventory->setBios($bios);
 
     if (
@@ -92,7 +96,16 @@ sub doInventory {
         $inventory->setHardware ({
             VMSYSTEM => 'VirtualBox'
         });
+    } elsif (
+        ($bios->{BIOSSERIAL} && ($bios->{BIOSSERIAL} =~ /VMware/i))
+         ||
+        ($bios->{SMODEL} && ($bios->{SMODEL} eq 'VirtualBox'))
+       ) {
+        $inventory->setHardware ({
+            VMSYSTEM => 'VMware'
+        });
     }
+
 }
 
 1;
