@@ -27,7 +27,6 @@ sub doInventory {
         'winmgmts:{impersonationLevel=impersonate}!\\\\.\\root\\cimv2'
     ) or die "WMI connection failed: " . Win32::OLE->LastError();
 
-    my $defaultGw;
     my %ips;
     my @ip6s;
     my @interfaces;
@@ -38,14 +37,22 @@ sub doInventory {
         'SELECT * FROM Win32_NetworkAdapterConfiguration'
     );
     foreach my $nic (in $nics) {
-        my $interface = $interfaces[$nic->Index];
-
-        $interface->{DESCRIPTION} = $nic->Description;
+        my $interface = {
+            DESCRIPTION => $nic->Description,
+            STATUS      => $nic->IPEnabled ? "Up" : "Down",
+            IPDHCP      => $nic->DHCPServer,
+            MACADDR     => $nic->MACAddress,
+            MTU         => $nic->MTU
+        };
 
         foreach (@{$nic->DefaultIPGateway || []}) {
             $defaultgateways{$_} = 1;
         }
 
+        if ($nic->DefaultIPGateway) {
+            $interface->{IPGATEWAY} = $nic->DefaultIPGateway()->[0];
+        }
+
         foreach (@{$nic->DNSServerSearchOrder || []}) {
             $dns{$_} = 1;
         }
@@ -70,39 +77,37 @@ sub doInventory {
             }
         }
 
-        if ($nic->DefaultIPGateway) {
-            $interface->{IPGATEWAY} = $nic->DefaultIPGateway()->[0];
-        }
-
-        $interface->{STATUS}  = $nic->IPEnabled ? "Up" : "Down";
-        $interface->{IPDHCP}  = $nic->DHCPServer;
-        $interface->{MACADDR} = $nic->MACAddress;
-        $interface->{MTU}     = $nic->MTU;
-
+        $interfaces[$nic->Index] = $interface;
     }
 
     $nics = $WMIService->ExecQuery('SELECT * FROM Win32_NetworkAdapter');
     foreach my $nic (in $nics) {
+	my $interface = $interfaces[$nic->Index];
+
         # http://comments.gmane.org/gmane.comp.monitoring.fusion-inventory.devel/34
         next unless $nic->PNPDeviceID;
 
-        my $interface = {
-		SPEED       => $nic->Speed,
-		MACADDR     => $nic->MACAddress,
-		PNPDEVICEID => $nic->PNPDeviceID,
-	};
+	$interface->{SPEED}       = $nic->Speed;
+	$interface->{MACADDR}     = $nic->MACAddress;
+	$interface->{PNPDEVICEID} = $nic->PNPDeviceID;
 
         # PhysicalAdapter only work on OS > XP
         if (defined $nic->PhysicalAdapter) {
             $interface->{VIRTUALDEV} = $nic->PhysicalAdapter ? 0 : 1;
         # http://forge.fusioninventory.org/issues/1166 
-        } elsif ($interface->{description} =~ /RAS Async Adapter/i) {
+        } elsif ($interface->{description}
+              && $interface->{description} =~ /RAS/
+              && $interface->{description} =~ /Adapter/i) {
             $interface->{VIRTUALDEV} = 1;
         } else {
 	    $interface->{VIRTUALDEV} = $nic->PNPDeviceID =~ /^ROOT/ ? 1 : 0;
         }
 
-        push @interfaces, $interface;
+        if (defined $nic->AdapterType) {
+            $interface->{TYPE} = $nic->AdapterType;
+            $interface->{TYPE} =~ s/Ethernet.*/Ethernet/;
+        }
+
     }
 
     foreach my $interface (@interfaces) {
