@@ -25,13 +25,14 @@ my %fields = (
     INPUTS      => [ qw/NAME MANUFACTURER CAPTION DESCRIPTION INTERFACE LAYOUT
 	                POINTINGTYPE TYPE/ ],
     MEMORIES    => [qw/CAPACITY CAPTION FORMFACTOR REMOVABLE PURPOSE SPEED
-                       SERIALNUMBER TYPE DESCRIPTION NUMSLOTS/ ],
+                       SERIALNUMBER TYPE DESCRIPTION NUMSLOTS MEMORYCORRECTION/ ],
     MODEMS      => [ qw/DESCRIPTION NAME/ ],
     MONITORS    => [ qw/BASE64 CAPTION DESCRIPTION MANUFACTURER SERIAL
                         UUENCODE/ ],
     NETWORKS    => [ qw/DESCRIPTION DRIVER IPADDRESS IPADDRESS6 IPDHCP IPGATEWAY
                         IPMASK IPSUBNET MACADDR MTU PCISLOT PNPDEVICEID STATUS
-		       	TYPE VIRTUALDEV SLAVES SPEED MANAGEMENT BSSID SSID/ ],
+                        TYPE VIRTUALDEV SLAVES SPEED MANAGEMENT BSSID SSID WWN
+                        MANUFACTURER FIRMWARE MODEL/ ],
     PORTS       => [ qw/CAPTION DESCRIPTION NAME TYPE/ ],
     PROCESSES   => [ qw/USER PID CPUUSAGE MEM VIRTUALMEMORY TTY STARTED CMD/ ],
     REGISTRY    => [ qw/NAME REGVALUE HIVE/ ],
@@ -52,7 +53,7 @@ my %fields = (
                         PRINTPROCESSOR SERIAL/ ],
     VIRTUALMACHINES => [ qw/MEMORY NAME UUID STATUS SUBSYSTEM VMTYPE VCPU
                             VMID MAC COMMENT OWNER/ ],
-    LOGICAL_VOLUMES => [ qw/LV_NAME VGN_AME ATTR SIZE LV_UUID SEG_COUNT/ ],
+    LOGICAL_VOLUMES => [ qw/LV_NAME VGN_AME ATTR SIZE LV_UUID SEG_COUNT VG_UUID/ ],
     PHYSICAL_VOLUMES => [ qw/DEVICE PV_NAME PV_PE_COUNT PV_UUID FORMAT ATTR SIZE FREE PE_SIZE/ ],
     VOLUME_GROUPS => [ qw/VG_NAME PV_COUNT LV_COUNT ATTR SIZE FREE VG_UUID VG_EXTENT_SIZE/ ],
 
@@ -196,7 +197,21 @@ sub computeLegacyValues {
             PROCESSORS => $cpu->{SPEED},
             PROCESSORT => $cpu->{NAME},
         });
-}
+    }
+
+    # network related values
+    my $interfaces = $self->{content}->{NETWORKS};
+    if ($interfaces) {
+        my @ip_addresses =
+            grep { ! /^127/ }
+            grep { $_ }
+            map { $_->{IPADDRESS} }
+            @$interfaces;
+
+        $self->setHardware({
+            IPADDR => join('/', @ip_addresses),
+        });
+    }
 
     # user-related values
     my $users = $self->{content}->{USERS};
@@ -292,31 +307,6 @@ sub checkContent {
     my $missing = 0;
     my $content = $self->{content};
 
-    if (!$content->{NETWORKS}->[0]->{MACADDR}) {
-        $logger->debug('Missing value: MAC address of first network card');
-        $missing++;
-    }
-    if (!$content->{BIOS}->{SSN}) {
-        $logger->debug('Missing value: serial number');
-        $missing++;
-    }
-    if (!$content->{HARDWARE}->{NAME}) {
-        $logger->debug('Missing value: hostname');
-        $missing++;
-    }
-    if (!$content->{HARDWARE}->{UUID}) {
-        $logger->debug('Missing value: UUID');
-        $missing++;
-    }
-
-    if ($missing) {
-        $logger->debug(
-            'Important value(s) to identify the computer are missing. ' .
-            'Depending on how the server identify duplicated machine, ' .
-            'this may create zombie computer in your data base.'
-        );
-    }
-
 }
 
 sub computeChecksum {
